@@ -58,8 +58,8 @@ use warnings;
 
 use base 'NetSDS::Class::Abstract';
 
-use NetSDS;
-use version; our $VERSION = NetSDS->VERSION;
+
+use version; our $VERSION = '1.200';
 
 use NetSDS::Logger;
 use NetSDS::Conf;
