@@ -65,8 +65,8 @@ use warnings;
 
 use base qw(Class::Accessor Class::ErrorHandler);
 
-use NetSDS;
-use version; our $VERSION = NetSDS->VERSION;
+
+use version; our $VERSION = '1.200';
 
 #===============================================================================
 
